/***************************************************************************//**
* \file sSPI.h
* \version 2.0
*
*  This file provides constants and parameter values for the SPI component.
*
********************************************************************************
* \copyright
* Copyright 2016-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(sSPI_CY_SCB_SPI_PDL_H)
#define sSPI_CY_SCB_SPI_PDL_H

#include "cyfitter.h"
#include "scb/cy_scb_spi.h"

#if defined(__cplusplus)
extern "C" {
#endif

/***************************************
*        Function Prototypes
***************************************/
/**
* \addtogroup group_general
* @{
*/
/* Component specific functions. */
void sSPI_Start(void);

/* Basic functions. */
__STATIC_INLINE cy_en_scb_spi_status_t sSPI_Init(cy_stc_scb_spi_config_t const *config);
__STATIC_INLINE void sSPI_DeInit(void);
__STATIC_INLINE void sSPI_Enable(void);
__STATIC_INLINE void sSPI_Disable(void);

/* Register callback. */
__STATIC_INLINE void sSPI_RegisterCallback(cy_cb_scb_spi_handle_events_t callback);

/* Bus state. */
__STATIC_INLINE bool sSPI_IsBusBusy(void);

/* Slave select control. */
__STATIC_INLINE void sSPI_SetActiveSlaveSelect(cy_en_scb_spi_slave_select_t slaveSelect);
__STATIC_INLINE void sSPI_SetActiveSlaveSelectPolarity(cy_en_scb_spi_slave_select_t slaveSelect, 
                                                                   cy_en_scb_spi_polarity_t polarity);

/* Low level: read. */
__STATIC_INLINE uint32_t sSPI_Read(void);
__STATIC_INLINE uint32_t sSPI_ReadArray(void *buffer, uint32_t size);
__STATIC_INLINE uint32_t sSPI_GetRxFifoStatus(void);
__STATIC_INLINE void     sSPI_ClearRxFifoStatus(uint32_t clearMask);
__STATIC_INLINE uint32_t sSPI_GetNumInRxFifo(void);
__STATIC_INLINE void     sSPI_ClearRxFifo(void);

/* Low level: write. */
__STATIC_INLINE uint32_t sSPI_Write(uint32_t data);
__STATIC_INLINE uint32_t sSPI_WriteArray(void *buffer, uint32_t size);
__STATIC_INLINE void     sSPI_WriteArrayBlocking(void *buffer, uint32_t size);
__STATIC_INLINE uint32_t sSPI_GetTxFifoStatus(void);
__STATIC_INLINE void     sSPI_ClearTxFifoStatus(uint32_t clearMask);
__STATIC_INLINE uint32_t sSPI_GetNumInTxFifo(void);
__STATIC_INLINE bool     sSPI_IsTxComplete(void);
__STATIC_INLINE void     sSPI_ClearTxFifo(void);

/* Master/slave specific status. */
__STATIC_INLINE uint32_t sSPI_GetSlaveMasterStatus(void);
__STATIC_INLINE void     sSPI_ClearSlaveMasterStatus(uint32_t clearMask);

/* High level: transfer functions. */
__STATIC_INLINE cy_en_scb_spi_status_t sSPI_Transfer(void *txBuffer, void *rxBuffer, uint32_t size);
__STATIC_INLINE void     sSPI_AbortTransfer(void);
__STATIC_INLINE uint32_t sSPI_GetTransferStatus(void);
__STATIC_INLINE uint32_t sSPI_GetNumTransfered(void);

/* Interrupt handler */
__STATIC_INLINE void sSPI_Interrupt(void);
/** @} group_general */


/***************************************
*    Variables with External Linkage
***************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8_t sSPI_initVar;
extern cy_stc_scb_spi_config_t const sSPI_config;
extern cy_stc_scb_spi_context_t sSPI_context;
/** @} group_globals */


/***************************************
*         Preprocessor Macros
***************************************/
/**
* \addtogroup group_macros
* @{
*/
/** The pointer to the base address of the hardware */
#define sSPI_HW     ((CySCB_Type *) sSPI_SCB__HW)

/** The slave select line 0 constant which takes into account pin placement */
#define sSPI_SPI_SLAVE_SELECT0    ( (cy_en_scb_spi_slave_select_t) sSPI_SCB__SS0_POSITION)

/** The slave select line 1 constant which takes into account pin placement */
#define sSPI_SPI_SLAVE_SELECT1    ( (cy_en_scb_spi_slave_select_t) sSPI_SCB__SS1_POSITION)

/** The slave select line 2 constant which takes into account pin placement */
#define sSPI_SPI_SLAVE_SELECT2    ( (cy_en_scb_spi_slave_select_t) sSPI_SCB__SS2_POSITION)

/** The slave select line 3 constant which takes into account pin placement */
#define sSPI_SPI_SLAVE_SELECT3    ((cy_en_scb_spi_slave_select_t) sSPI_SCB__SS3_POSITION)
/** @} group_macros */


/***************************************
*    In-line Function Implementation
***************************************/

/*******************************************************************************
* Function Name: sSPI_Init
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_scb_spi_status_t sSPI_Init(cy_stc_scb_spi_config_t const *config)
{
    return Cy_SCB_SPI_Init(sSPI_HW, config, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_DeInit
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_DeInit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_DeInit(void)
{
    Cy_SCB_SPI_DeInit(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_Enable
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Enable() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_Enable(void)
{
    Cy_SCB_SPI_Enable(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_Disable
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Disable() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_Disable(void)
{
    Cy_SCB_SPI_Disable(sSPI_HW, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_RegisterCallback
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_RegisterCallback() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_RegisterCallback(cy_cb_scb_spi_handle_events_t callback)
{
    Cy_SCB_SPI_RegisterCallback(sSPI_HW, callback, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_IsBusBusy
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_IsBusBusy() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE bool sSPI_IsBusBusy(void)
{
    return Cy_SCB_SPI_IsBusBusy(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_SetActiveSlaveSelect
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_SetActiveSlaveSelect() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_SetActiveSlaveSelect(cy_en_scb_spi_slave_select_t slaveSelect)
{
    Cy_SCB_SPI_SetActiveSlaveSelect(sSPI_HW, slaveSelect);
}


/*******************************************************************************
* Function Name: sSPI_SetActiveSlaveSelectPolarity
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_SetActiveSlaveSelectPolarity() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_SetActiveSlaveSelectPolarity(cy_en_scb_spi_slave_select_t slaveSelect, 
                                                                   cy_en_scb_spi_polarity_t polarity)
{
    Cy_SCB_SPI_SetActiveSlaveSelectPolarity(sSPI_HW, slaveSelect, polarity);
}


/*******************************************************************************
* Function Name: sSPI_Read
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Read() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_Read(void)
{
    return Cy_SCB_SPI_Read(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ReadArray
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ReadArray() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_ReadArray(void *buffer, uint32_t size)
{
    return Cy_SCB_SPI_ReadArray(sSPI_HW, buffer, size);
}


/*******************************************************************************
* Function Name: sSPI_GetRxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetRxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetRxFifoStatus(void)
{
    return Cy_SCB_SPI_GetRxFifoStatus(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ClearRxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ClearRxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_ClearRxFifoStatus(uint32_t clearMask)
{
    Cy_SCB_SPI_ClearRxFifoStatus(sSPI_HW, clearMask);
}


/*******************************************************************************
* Function Name: sSPI_GetNumInRxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_GetNumInRxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetNumInRxFifo(void)
{
    return Cy_SCB_GetNumInRxFifo(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ClearRxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ClearRxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_ClearRxFifo(void)
{
    Cy_SCB_SPI_ClearRxFifo(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_Write
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Write() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_Write(uint32_t data)
{
    return Cy_SCB_SPI_Write(sSPI_HW, data);
}


/*******************************************************************************
* Function Name: sSPI_WriteArray
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_WriteArray() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_WriteArray(void *buffer, uint32_t size)
{
    return Cy_SCB_SPI_WriteArray(sSPI_HW, buffer, size);
}


/*******************************************************************************
* Function Name: sSPI_WriteArrayBlocking
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_WriteArrayBlocking() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_WriteArrayBlocking(void *buffer, uint32_t size)
{
    Cy_SCB_SPI_WriteArrayBlocking(sSPI_HW, buffer, size);
}


/*******************************************************************************
* Function Name: sSPI_GetTxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetTxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetTxFifoStatus(void)
{
    return Cy_SCB_SPI_GetTxFifoStatus(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ClearTxFifoStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ClearTxFifoStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_ClearTxFifoStatus(uint32_t clearMask)
{
    Cy_SCB_SPI_ClearTxFifoStatus(sSPI_HW, clearMask);
}


/*******************************************************************************
* Function Name: sSPI_GetNumInTxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetNumInTxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetNumInTxFifo(void)
{
    return Cy_SCB_SPI_GetNumInTxFifo(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_IsTxComplete
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_IsTxComplete() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE bool sSPI_IsTxComplete(void)
{
    return Cy_SCB_SPI_IsTxComplete(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ClearTxFifo
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ClearTxFifo() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_ClearTxFifo(void)
{
    Cy_SCB_SPI_ClearTxFifo(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_GetSlaveMasterStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetSlaveMasterStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetSlaveMasterStatus(void)
{
    return Cy_SCB_SPI_GetSlaveMasterStatus(sSPI_HW);
}


/*******************************************************************************
* Function Name: sSPI_ClearSlaveMasterStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_ClearSlaveMasterStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_ClearSlaveMasterStatus(uint32_t clearMask)
{
    Cy_SCB_SPI_ClearSlaveMasterStatus(sSPI_HW, clearMask);
}


/*******************************************************************************
* Function Name: sSPI_Transfer
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Transfer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_scb_spi_status_t sSPI_Transfer(void *txBuffer, void *rxBuffer, uint32_t size)
{
    return Cy_SCB_SPI_Transfer(sSPI_HW, txBuffer, rxBuffer, size, &sSPI_context);
}

/*******************************************************************************
* Function Name: sSPI_AbortTransfer
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_AbortTransfer() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_AbortTransfer(void)
{
    Cy_SCB_SPI_AbortTransfer(sSPI_HW, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_GetTransferStatus
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetTransferStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetTransferStatus(void)
{
    return Cy_SCB_SPI_GetTransferStatus(sSPI_HW, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_GetNumTransfered
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_GetNumTransfered() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t sSPI_GetNumTransfered(void)
{
    return Cy_SCB_SPI_GetNumTransfered(sSPI_HW, &sSPI_context);
}


/*******************************************************************************
* Function Name: sSPI_Interrupt
****************************************************************************//**
*
* Invokes the Cy_SCB_SPI_Interrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void sSPI_Interrupt(void)
{
    Cy_SCB_SPI_Interrupt(sSPI_HW, &sSPI_context);
}


#if defined(__cplusplus)
}
#endif

#endif /* sSPI_CY_SCB_SPI_PDL_H */


/* [] END OF FILE */
