/*
    Test Script:
    Reads single byte from UART and updates buffer. Pushbutton sends buffer to SPI. SPI echoes back to UART.
*/

#include "project.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

// SPI settings
#define mspi_buffer_size (1UL)
char mspi_bufferTx[mspi_buffer_size];
char mspi_bufferRx[mspi_buffer_size];
#define sspi_buffer_size (1UL)
char sspi_bufferTx[sspi_buffer_size];
char sspi_bufferTx_clear[sspi_buffer_size];
char sspi_bufferRx[sspi_buffer_size];
cy_en_scb_spi_status_t mspi_error_status;
cy_en_scb_spi_status_t sspi_error_status;
uint32_t mspi_status;
uint32_t sspi_status;

// GPIO Settings
#define LED_Green_on Cy_GPIO_Write(P7_1_PORT, P7_1_NUM, 0);
#define LED_Green_off Cy_GPIO_Write(P7_1_PORT, P7_1_NUM, 1);
#define LED_Red_on Cy_GPIO_Write(P6_3_PORT, P6_3_NUM, 0);
#define LED_Red_off Cy_GPIO_Write(P6_3_PORT, P6_3_NUM, 1);

// UART Settings
volatile char serial_data_in = 0;
volatile bool serial_receive = false;
volatile char mspi_data_in = 0;
volatile bool mspi_ready_to_send = false;
volatile bool mspi_send_done = false;

char spi_send(char data)
{
    mspi_bufferTx[0] = data;
    mspi_error_status = Cy_SCB_SPI_Transfer(mSPI_HW, mspi_bufferTx, mspi_bufferRx, sizeof(mspi_bufferTx), &mSPI_context);
    
    if(mspi_error_status == CY_SCB_SPI_SUCCESS)
    {
        do
        {
            mspi_status  = Cy_SCB_SPI_GetTransferStatus(mSPI_HW, &mSPI_context);
            Cy_SysLib_Delay(CY_SCB_WAIT_1_UNIT);            
        } while (0UL != (mspi_status & CY_SCB_SPI_TRANSFER_ACTIVE));
        return mspi_bufferRx[0];
    }
    
    else
    {
        return 0;
    }
    mspi_send_done = true;
}

//void spi_send_2(uint8 data_send)
//{
//    while(Cy_SCB_SPI_IsBusBusy(mSPI_HW)){}
//    Cy_SCB_SPI_Write(mSPI_HW, data_send);
//    Cy_SysLib_Delay(1);
//    while (!Cy_SCB_SPI_IsTxComplete(mSPI_HW)){}
//    uint16_t regReturn;
//}

void mspi_isr(void)
{
    Cy_SCB_SPI_Interrupt(mSPI_HW, &mSPI_context);
    mspi_send_done = true ;
}

void sspi_isr(void)
{
    LED_Red_on; LED_Green_on; CyDelay(500);
    Cy_SCB_SPI_Interrupt(sSPI_HW, &sSPI_context);
}

void PushButton_isr(void)
{
    //spi_bufferTx[0] = serial_data_in;
    mspi_ready_to_send = true;
}

void UART_Rx_ready_isr(void)
{
    if((UART_HW->INTR_RX_MASKED & SCB_INTR_RX_MASKED_NOT_EMPTY_Msk ) != 0){
        serial_receive = true;
        // Must read serial buffer then clear its interrupt
        serial_data_in = UART_Get();
        UART_HW->INTR_RX = UART_HW->INTR_RX & SCB_INTR_RX_NOT_EMPTY_Msk;
    }
}

int main(void)
{
    char message1[] = "PSoC Ready\n";
    char message2[] = "\nSerial Data in: ";
    char message3[] = "\nSPI Data in: ";
    sspi_bufferTx_clear[0] = 5;
    
    //char spi_data_in_string[10];
    uint8_t i=0;
    for(i=0; i<2;i++){
        LED_Red_off; LED_Green_off; CyDelay(100);
        LED_Red_on; LED_Green_on; CyDelay(100);
    }
    
    Cy_SCB_SPI_Init(mSPI_HW, &mSPI_config, &mSPI_context);
    Cy_SCB_SPI_Enable(mSPI_HW);
    Cy_SCB_SPI_Init(sSPI_HW, &sSPI_config, &sSPI_context);
    Cy_SCB_SPI_Enable(sSPI_HW);
    
    // Setup Interrupts
    Cy_SysInt_Init(&UART_Rx_Ready_cfg, UART_Rx_ready_isr);
    NVIC_EnableIRQ(UART_Rx_Ready_cfg.intrSrc);
    Cy_SysInt_Init(&PushButton_isr_cfg, PushButton_isr);
    NVIC_EnableIRQ(PushButton_isr_cfg.intrSrc);
    Cy_SysInt_Init(&mSPI_SCB_IRQ_cfg, &mspi_isr);
    NVIC_EnableIRQ(mSPI_SCB_IRQ_cfg.intrSrc);
    Cy_SysInt_Init(&sSPI_SCB_IRQ_cfg, &sspi_isr);
    NVIC_EnableIRQ((IRQn_Type) sSPI_SCB_IRQ_cfg.intrSrc);
    //NVIC_EnableIRQ(sSPI_SCB_IRQ_cfg.intrSrc);
    __enable_irq();
    
    //Cy_SCB_SPI_SetActiveSlaveSelect(mSPI_HW, mSPI_SPI_SLAVE_SELECT0);
    //Cy_SCB_SPI_SetActiveSlaveSelect(sSPI_HW, sSPI_SPI_SLAVE_SELECT0);

    // Reset sSPI TX buffer
    Cy_SCB_SPI_WriteArrayBlocking(sSPI_HW, sspi_bufferTx_clear, sizeof(sspi_bufferTx));
    
    UART_Start();
     do{
        }while(!UART_IsTxComplete());
    
    Cy_SCB_UART_PutString(UART_HW, message1);

    for(;;)
    {
        for(i=0; i<2;i++){
            LED_Red_off;
            LED_Green_off; CyDelay(100);
            LED_Green_on; CyDelay(100);
            
            if(serial_receive)
            {
                LED_Red_off; LED_Green_off; CyDelay(100);
                LED_Red_on; LED_Green_on; CyDelay(100);
                Cy_SCB_UART_PutArray(UART_HW, message2, sizeof(message2));
                UART_Put(serial_data_in);
                serial_receive = false;
            }
            
            if(mspi_ready_to_send)
            {
                mspi_data_in = spi_send(serial_data_in);
                Cy_SCB_UART_PutArray(UART_HW, message3, sizeof(message3));
//                UART_Put(mspi_data_in);
                if(mspi_send_done)
                {
                    do
                    {
                        sspi_status  = Cy_SCB_SPI_GetTransferStatus(sSPI_HW, &sSPI_context);
                    }while ((0UL != (sspi_status & CY_SCB_SPI_TRANSFER_ACTIVE)));
                    
                    sspi_bufferTx[0] = sspi_bufferRx[0];
                    Cy_SCB_SPI_Transfer(sSPI_HW, sspi_bufferTx, sspi_bufferRx, sizeof(sspi_bufferTx), &sSPI_context);
                    
                    UART_Put(sspi_bufferRx[0]) ;
                    mspi_send_done = false;
                }
                mspi_ready_to_send = false;
            }
        }
    }
}

